[gnome-shell] main: Let SWITCH_PANELS keybinding through at login screen



commit 2e48dbf6ee8003c84e4e78aabfb92bd35f008a00
Author: Ray Strode <rstrode redhat com>
Date:   Sat Sep 17 15:43:46 2011 -0400

    main: Let SWITCH_PANELS keybinding through at login screen
    
    Users depend on being able to switch focus between the panel
    and the login screen using ctrl-alt-tab.
    
    Because the login screen has no overview, we were short circuiting
    some code that needs to get run to support ctrl-alt-tab.
    
    This commit changes the short-circuit code to only run for user
    sessions.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=659177

 js/ui/main.js |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/js/ui/main.js b/js/ui/main.js
index 04fb8a2..d926d0a 100644
--- a/js/ui/main.js
+++ b/js/ui/main.js
@@ -595,9 +595,9 @@ function _globalKeyPressHandler(actor, event) {
         return true;
     }
 
     // Other bindings are only available when the overview is up and
     // no modal dialog is present.
-    if (!overview.visible || modalCount > 1)
+    if (global.session_type == Shell.SessionType.USER && (!overview.visible || modalCount > 1))
         return false;
 
     // This isn't a Meta.KeyBindingAction yet
@@ -595,9 +595,9 @@ function _globalKeyPressHandler(actor, event) {
     }
 
-    // Other bindings are only available when the overview is up and
+    // Other bindings are only available to the user session when the overview is up and
     // no modal dialog is present.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]